tpRigToolkit-tools-interpolateit
============================================================

Tool to store/blend interpolate states of objects

.. image:: https://travis-ci.com/tpRigToolkit/tpRigToolkit-tools-interpolateit.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpRigToolkit/tpRigToolkit-tools-interpolateit

.. image:: https://coveralls.io/repos/github/tpRigToolkit/tpRigToolkit-tools-interpolateit/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpRigToolkit/tpRigToolkit-tools-interpolateit?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpRigToolkit.github.io/tpRigToolkit-tools-interpolateit/

.. image:: https://img.shields.io/github/license/tpRigToolkit/tpRigToolkit-tools-interpolateit
    :target: https://github.com/tpRigToolkit/tpRigToolkit-tools-interpolateit/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpRigToolkit-tools-interpolateit?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpRigToolkit-tools-interpolateit/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/